@@ -6,10 +6,11 @@
 #' will be used. 
 #' 
 #' @param verbose boolean deciding whether status information/updates should be shown or not
+#' @param .testmode boolean switch only relevant for internal testing (will simulate user inputs)
 #' @author Jan Philipp Dietrich
 #' @seealso \code{\link{initializeConfig}}, \code{\link{getConfig}}, \code{\link{setConfig}}
 #' 
-getMainfolder <- function(verbose=TRUE) {
+getMainfolder <- function(verbose=TRUE, .testmode = FALSE) {
   
   # option MADRAT_MAINFOLDER set?
   mainfolder <- getOption("MADRAT_MAINFOLDER")
@@ -20,37 +21,40 @@ getMainfolder <- function(verbose=TRUE) {
   if(!is.na(mainfolder)) return(mainfolder)
   
   # ask for folder to use
-  if(interactive()){
+  if(interactive() || .testmode){
     repeat {
       s <- tolower(readline("madrat mainfolder for data storage not set! Do you want to set it now? (y/n) "))
+      if(.testmode) s <- "y"
       if(s %in% c("y","n")) break
     }
     if(s=="y") {
       repeat {
         folder <- gsub('"',"",readline("Please enter main folder path: "), fixed = TRUE)
+        if(.testmode) folder <- paste0(tempdir(),"/testmaindir")
         if(!dir.exists(folder)) {
           s <- tolower(readline("Directory does not exist. Should it be created? (y/n) "))
+          if(.testmode) s <- "y"
           if(s=="y") dir.create(folder, recursive = TRUE)
         }
         if(dir.exists(folder)) {
           mainfolder <- normalizePath(folder, winslash = "/")
           repeat {
             s <- tolower(readline("Should this path be added to your global .Rprofile to be used permanently? (y/n) "))
+            if(.testmode) s <- "n"
             if(s %in% c("y","n")) break
           }
-          if(s=="y") write(c("","# Set mainfolder for madrat package",
-                             paste0('options(MADRAT_MAINFOLDER="',mainfolder,'")'),"")
-                           , file="~/.Rprofile", append=TRUE)
+          if(s=="y") write(c("","# Set mainfolder for madrat package", paste0('options(MADRAT_MAINFOLDER="',mainfolder,'")'),"") , file="~/.Rprofile", append=TRUE)
+          options(MADRAT_MAINFOLDER=mainfolder)
           return(mainfolder)
         } else {
-          base::cat("Please specify either an existing folder or a folder you would like to create!\n")
+          message("Please specify either an existing folder or a folder you would like to create!")
         }
       }
     } 
   } 
   
   # use temporary directory
-  if(verbose) base::cat("Temporary main folder will be used..\n")
+  if(verbose) message("Temporary main folder will be used..")
   mainfolder <- paste0(tempdir(),"/madrat")
   if(!dir.exists(mainfolder)) dir.create(mainfolder)
   return(mainfolder)
